Class: Aws::InternetMonitor::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::InternetMonitor::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-internetmonitor/client.rb,
sig/client.rbs
Overview
An API client for InternetMonitor. To construct a client, you need to configure a :region and :credentials.
client = Aws::InternetMonitor::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateMonitorResponseSuccess, _DeleteMonitorResponseSuccess, _GetHealthEventResponseSuccess, _GetInternetEventResponseSuccess, _GetMonitorResponseSuccess, _GetQueryResultsResponseSuccess, _GetQueryStatusResponseSuccess, _ListHealthEventsResponseSuccess, _ListInternetEventsResponseSuccess, _ListMonitorsResponseSuccess, _ListTagsForResourceResponseSuccess, _StartQueryResponseSuccess, _StopQueryResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateMonitorResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_monitor(params = {}) ⇒ Types::CreateMonitorOutput
Creates a monitor in Amazon CloudWatch Internet Monitor.
-
#delete_monitor(params = {}) ⇒ Struct
Deletes a monitor in Amazon CloudWatch Internet Monitor.
-
#get_health_event(params = {}) ⇒ Types::GetHealthEventOutput
Gets information that Amazon CloudWatch Internet Monitor has created and stored about a health event for a specified monitor.
-
#get_internet_event(params = {}) ⇒ Types::GetInternetEventOutput
Gets information that Amazon CloudWatch Internet Monitor has generated about an internet event.
-
#get_monitor(params = {}) ⇒ Types::GetMonitorOutput
Gets information about a monitor in Amazon CloudWatch Internet Monitor based on a monitor name.
-
#get_query_results(params = {}) ⇒ Types::GetQueryResultsOutput
Return the data for a query with the Amazon CloudWatch Internet Monitor query interface.
-
#get_query_status(params = {}) ⇒ Types::GetQueryStatusOutput
Returns the current status of a query for the Amazon CloudWatch Internet Monitor query interface, for a specified query ID and monitor.
-
#list_health_events(params = {}) ⇒ Types::ListHealthEventsOutput
Lists all health events for a monitor in Amazon CloudWatch Internet Monitor.
-
#list_internet_events(params = {}) ⇒ Types::ListInternetEventsOutput
Lists internet events that cause performance or availability issues for client locations.
-
#list_monitors(params = {}) ⇒ Types::ListMonitorsOutput
Lists all of your monitors for Amazon CloudWatch Internet Monitor and their statuses, along with the Amazon Resource Name (ARN) and name of each monitor.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags for a resource.
-
#start_query(params = {}) ⇒ Types::StartQueryOutput
Start a query to return data for a specific query type for the Amazon CloudWatch Internet Monitor query interface.
-
#stop_query(params = {}) ⇒ Struct
Stop a query that is progress for a specific monitor.
-
#tag_resource(params = {}) ⇒ Struct
Adds a tag to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a resource.
-
#update_monitor(params = {}) ⇒ Types::UpdateMonitorOutput
Updates a monitor.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-internetmonitor/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1686 1687 1688 |
# File 'lib/aws-sdk-internetmonitor/client.rb', line 1686 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1689 1690 1691 |
# File 'lib/aws-sdk-internetmonitor/client.rb', line 1689 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 |
# File 'lib/aws-sdk-internetmonitor/client.rb', line 1659 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::InternetMonitor') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-internetmonitor' context[:gem_version] = '1.55.0' Seahorse::Client::Request.new(handlers, context) end |
#create_monitor(params = {}) ⇒ Types::CreateMonitorOutput
Creates a monitor in Amazon CloudWatch Internet Monitor. A monitor is built based on information from the application resources that you add: VPCs, Network Load Balancers (NLBs), Amazon CloudFront distributions, and Amazon WorkSpaces directories. Internet Monitor then publishes internet measurements from Amazon Web Services that are specific to the city-networks. That is, the locations and ASNs (typically internet service providers or ISPs), where clients access your application. For more information, see Using Amazon CloudWatch Internet Monitor in the Amazon CloudWatch User Guide.
When you create a monitor, you choose the percentage of traffic that you want to monitor. You can also set a maximum limit for the number of city-networks where client traffic is monitored, that caps the total traffic that Internet Monitor monitors. A city-network maximum is the limit of city-networks, but you only pay for the number of city-networks that are actually monitored. You can update your monitor at any time to change the percentage of traffic to monitor or the city-networks maximum. For more information, see Choosing a city-network maximum value in the Amazon CloudWatch User Guide.
87 |
# File 'sig/client.rbs', line 87
def create_monitor: (
|
#delete_monitor(params = {}) ⇒ Struct
Deletes a monitor in Amazon CloudWatch Internet Monitor.
109 |
# File 'sig/client.rbs', line 109
def delete_monitor: (
|
#get_health_event(params = {}) ⇒ Types::GetHealthEventOutput
Gets information that Amazon CloudWatch Internet Monitor has created and stored about a health event for a specified monitor. This information includes the impacted locations, and all the information related to the event, by location.
The information returned includes the impact on performance, availability, and round-trip time, information about the network providers (ASNs), the event type, and so on.
Information rolled up at the global traffic level is also returned, including the impact type and total traffic impact.
129 |
# File 'sig/client.rbs', line 129
def get_health_event: (
|
#get_internet_event(params = {}) ⇒ Types::GetInternetEventOutput
Gets information that Amazon CloudWatch Internet Monitor has generated about an internet event. Internet Monitor displays information about recent global health events, called internet events, on a global outages map that is available to all Amazon Web Services customers.
The information returned here includes the impacted location, when the
event started and (if the event is over) ended, the type of event
(PERFORMANCE or AVAILABILITY), and the status (ACTIVE or
RESOLVED).
147 |
# File 'sig/client.rbs', line 147
def get_internet_event: (
|
#get_monitor(params = {}) ⇒ Types::GetMonitorOutput
Gets information about a monitor in Amazon CloudWatch Internet Monitor based on a monitor name. The information returned includes the Amazon Resource Name (ARN), create time, modified time, resources included in the monitor, and status information.
169 |
# File 'sig/client.rbs', line 169
def get_monitor: (
|
#get_query_results(params = {}) ⇒ Types::GetQueryResultsOutput
Return the data for a query with the Amazon CloudWatch Internet
Monitor query interface. Specify the query that you want to return
results for by providing a QueryId and a monitor name.
For more information about using the query interface, including examples, see Using the Amazon CloudWatch Internet Monitor query interface in the Amazon CloudWatch Internet Monitor User Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
181 |
# File 'sig/client.rbs', line 181
def get_query_results: (
|
#get_query_status(params = {}) ⇒ Types::GetQueryStatusOutput
Returns the current status of a query for the Amazon CloudWatch
Internet Monitor query interface, for a specified query ID and
monitor. When you run a query, check the status to make sure that the
query has SUCCEEDED before you review the results.
-
QUEUED: The query is scheduled to run. -
RUNNING: The query is in progress but not complete. -
SUCCEEDED: The query completed sucessfully. -
FAILED: The query failed due to an error. -
CANCELED: The query was canceled.
194 |
# File 'sig/client.rbs', line 194
def get_query_status: (
|
#list_health_events(params = {}) ⇒ Types::ListHealthEventsOutput
Lists all health events for a monitor in Amazon CloudWatch Internet Monitor. Returns information for health events including the event start and end times, and the status.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
206 |
# File 'sig/client.rbs', line 206
def list_health_events: (
|
#list_internet_events(params = {}) ⇒ Types::ListInternetEventsOutput
Lists internet events that cause performance or availability issues for client locations. Amazon CloudWatch Internet Monitor displays information about recent global health events, called internet events, on a global outages map that is available to all Amazon Web Services customers.
You can constrain the list of internet events returned by providing a start time and end time to define a total time frame for events you want to list. Both start time and end time specify the time when an event started. End time is optional. If you don't include it, the default end time is the current time.
You can also limit the events returned to a specific status (ACTIVE
or RESOLVED) or type (PERFORMANCE or AVAILABILITY).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
223 |
# File 'sig/client.rbs', line 223
def list_internet_events: (
|
#list_monitors(params = {}) ⇒ Types::ListMonitorsOutput
Lists all of your monitors for Amazon CloudWatch Internet Monitor and their statuses, along with the Amazon Resource Name (ARN) and name of each monitor.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
239 |
# File 'sig/client.rbs', line 239
def list_monitors: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags for a resource. Tags are supported only for monitors in Amazon CloudWatch Internet Monitor.
252 |
# File 'sig/client.rbs', line 252
def list_tags_for_resource: (
|
#start_query(params = {}) ⇒ Types::StartQueryOutput
Start a query to return data for a specific query type for the Amazon
CloudWatch Internet Monitor query interface. Specify a time period for
the data that you want returned by using StartTime and EndTime.
You filter the query results to return by providing parameters that
you specify with FilterParameters.
For more information about using the query interface, including examples, see Using the Amazon CloudWatch Internet Monitor query interface in the Amazon CloudWatch Internet Monitor User Guide.
262 |
# File 'sig/client.rbs', line 262
def start_query: (
|
#stop_query(params = {}) ⇒ Struct
Stop a query that is progress for a specific monitor.
282 |
# File 'sig/client.rbs', line 282
def stop_query: (
|
#tag_resource(params = {}) ⇒ Struct
Adds a tag to a resource. Tags are supported only for monitors in Amazon CloudWatch Internet Monitor. You can add a maximum of 50 tags in Internet Monitor.
A minimum of one tag is required for this call. It returns an error if
you use the TagResource request with 0 tags.
292 |
# File 'sig/client.rbs', line 292
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a resource.
302 |
# File 'sig/client.rbs', line 302
def untag_resource: (
|
#update_monitor(params = {}) ⇒ Types::UpdateMonitorOutput
Updates a monitor. You can update a monitor to change the percentage of traffic to monitor or the maximum number of city-networks (locations and ASNs), to add or remove resources, or to change the status of the monitor. Note that you can't change the name of a monitor.
The city-network maximum that you choose is the limit, but you only pay for the number of city-networks that are actually monitored. For more information, see Choosing a city-network maximum value in the Amazon CloudWatch User Guide.
314 |
# File 'sig/client.rbs', line 314
def update_monitor: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1679 1680 1681 |
# File 'lib/aws-sdk-internetmonitor/client.rb', line 1679 def waiter_names [] end |