Class: Aws::InternetMonitor::Types::StartQueryInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::InternetMonitor::Types::StartQueryInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-internetmonitor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Time
The timestamp that is the end of the period that you want to retrieve data for with your query.
-
#filter_parameters ⇒ Array<Types::FilterParameter>
The
FilterParametersfield that you use with Amazon CloudWatch Internet Monitor queries is a string the defines how you want a query to be filtered. -
#linked_account_id ⇒ String
The account ID for an account that you've set up cross-account sharing for in Amazon CloudWatch Internet Monitor.
-
#monitor_name ⇒ String
The name of the monitor to query.
-
#query_type ⇒ String
The type of query to run.
-
#start_time ⇒ Time
The timestamp that is the beginning of the period that you want to retrieve data for with your query.
Instance Attribute Details
#end_time ⇒ Time
The timestamp that is the end of the period that you want to retrieve data for with your query.
1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 |
# File 'lib/aws-sdk-internetmonitor/types.rb', line 1821 class StartQueryInput < Struct.new( :monitor_name, :start_time, :end_time, :query_type, :filter_parameters, :linked_account_id) SENSITIVE = [] include Aws::Structure end |
#filter_parameters ⇒ Array<Types::FilterParameter>
The FilterParameters field that you use with Amazon CloudWatch
Internet Monitor queries is a string the defines how you want a
query to be filtered. The filter parameters that you can specify
depend on the query type, since each query type returns a different
set of Internet Monitor data.
For more information about specifying filter parameters, see Using the Amazon CloudWatch Internet Monitor query interface in the Amazon CloudWatch Internet Monitor User Guide.
1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 |
# File 'lib/aws-sdk-internetmonitor/types.rb', line 1821 class StartQueryInput < Struct.new( :monitor_name, :start_time, :end_time, :query_type, :filter_parameters, :linked_account_id) SENSITIVE = [] include Aws::Structure end |
#linked_account_id ⇒ String
The account ID for an account that you've set up cross-account sharing for in Amazon CloudWatch Internet Monitor. You configure cross-account sharing by using Amazon CloudWatch Observability Access Manager. For more information, see Internet Monitor cross-account observability in the Amazon CloudWatch Internet Monitor User Guide.
1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 |
# File 'lib/aws-sdk-internetmonitor/types.rb', line 1821 class StartQueryInput < Struct.new( :monitor_name, :start_time, :end_time, :query_type, :filter_parameters, :linked_account_id) SENSITIVE = [] include Aws::Structure end |
#monitor_name ⇒ String
The name of the monitor to query.
1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 |
# File 'lib/aws-sdk-internetmonitor/types.rb', line 1821 class StartQueryInput < Struct.new( :monitor_name, :start_time, :end_time, :query_type, :filter_parameters, :linked_account_id) SENSITIVE = [] include Aws::Structure end |
#query_type ⇒ String
The type of query to run. The following are the three types of queries that you can run using the Internet Monitor query interface:
-
MEASUREMENTS: Provides availability score, performance score, total traffic, and round-trip times, at 5 minute intervals. -
TOP_LOCATIONS: Provides availability score, performance score, total traffic, and time to first byte (TTFB) information, for the top location and ASN combinations that you're monitoring, by traffic volume. -
TOP_LOCATION_DETAILS: Provides TTFB for Amazon CloudFront, your current configuration, and the best performing EC2 configuration, at 1 hour intervals. -
OVERALL_TRAFFIC_SUGGESTIONS: Provides TTFB, using a 30-day weighted average, for all traffic in each Amazon Web Services location that is monitored. -
OVERALL_TRAFFIC_SUGGESTIONS_DETAILS: Provides TTFB, using a 30-day weighted average, for each top location, for a proposed Amazon Web Services location. Must provide an Amazon Web Services location to search. -
ROUTING_SUGGESTIONS: Provides the predicted average round-trip time (RTT) from an IP prefix toward an Amazon Web Services location for a DNS resolver. The RTT is calculated at one hour intervals, over a one hour period.
For lists of the fields returned with each query type and more information about how each type of query is performed, see Using the Amazon CloudWatch Internet Monitor query interface in the Amazon CloudWatch Internet Monitor User Guide.
1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 |
# File 'lib/aws-sdk-internetmonitor/types.rb', line 1821 class StartQueryInput < Struct.new( :monitor_name, :start_time, :end_time, :query_type, :filter_parameters, :linked_account_id) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The timestamp that is the beginning of the period that you want to retrieve data for with your query.
1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 |
# File 'lib/aws-sdk-internetmonitor/types.rb', line 1821 class StartQueryInput < Struct.new( :monitor_name, :start_time, :end_time, :query_type, :filter_parameters, :linked_account_id) SENSITIVE = [] include Aws::Structure end |